"""Kmmlu group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

# NO PARENT TASK MAPPING - each subtask mapped individually based on output_type

KMMLU_TASKS = {
    # Multiple_choice subtasks → kmmlu_mc.py (evaluator_name = "log_likelihoods")
    "kmmlu_accounting": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_agricultural_sciences": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_applied_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_applied_science_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_aviation_engineering_and_maintenance": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_biology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_chemical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_chemistry": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_civil_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_computer_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_construction": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_criminal_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_accounting": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_agricultural_sciences": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_applied_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_applied_science_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_aviation_engineering_and_maintenance": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_biology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_chemical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_chemistry": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_civil_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_computer_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_construction": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_criminal_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_ecology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_economics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_education": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_electrical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_electronics_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_energy_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_environmental_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_fashion": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_food_processing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_gas_technology_and_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_geomatics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_accounting": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_agricultural_sciences": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_applied_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_applied_science_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_aviation_engineering_and_maintenance": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_biology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_chemical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_chemistry": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_civil_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_computer_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_construction": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_criminal_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_ecology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_economics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_education": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_electrical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_electronics_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_energy_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_environmental_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_fashion": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_food_processing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_gas_technology_and_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_geomatics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_health": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_humss": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_humss_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_industrial_engineer": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_information_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_interior_architecture_and_design": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_korean_history": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_machine_design_and_manufacturing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_maritime_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_marketing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_materials_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_math": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_mechanical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_nondestructive_testing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_other": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_other_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_patent": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_political_science_and_sociology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_psychology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_public_safety": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_railway_and_automotive_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_real_estate": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_refrigerating_machinery": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_social_welfare": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_stem": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_stem_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_taxation": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_hard_telecommunications_and_wireless_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_health": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_humss": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_humss_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_industrial_engineer": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_information_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_interior_architecture_and_design": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_korean_history": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_machine_design_and_manufacturing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_maritime_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_marketing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_materials_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_math": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_mechanical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_nondestructive_testing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_other": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_other_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_patent": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_political_science_and_sociology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_psychology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_public_safety": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_railway_and_automotive_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_real_estate": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_refrigerating_machinery": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_social_welfare": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_stem": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_stem_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_taxation": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_direct_telecommunications_and_wireless_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_ecology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_economics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_education": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_electrical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_electronics_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_energy_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_environmental_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_fashion": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_food_processing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_gas_technology_and_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_geomatics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_accounting": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_agricultural_sciences": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_applied_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_applied_science_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_aviation_engineering_and_maintenance": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_biology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_chemical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_chemistry": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_civil_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_computer_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_construction": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_criminal_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_ecology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_economics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_education": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_electrical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_electronics_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_energy_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_environmental_science": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_fashion": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_food_processing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_gas_technology_and_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_geomatics": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_health": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_humss": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_humss_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_industrial_engineer": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_information_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_interior_architecture_and_design": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_korean_history": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_machine_design_and_manufacturing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_maritime_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_marketing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_materials_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_math": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_mechanical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_nondestructive_testing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_other": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_other_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_patent": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_political_science_and_sociology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_psychology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_public_safety": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_railway_and_automotive_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_real_estate": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_refrigerating_machinery": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_social_welfare": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_stem": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_stem_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_taxation": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_hard_telecommunications_and_wireless_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_health": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_humss": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_humss_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_industrial_engineer": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_information_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_interior_architecture_and_design": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_korean_history": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_law": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_machine_design_and_manufacturing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_management": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_maritime_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_marketing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_materials_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_math": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_mechanical_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_nondestructive_testing": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_other": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_other_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_patent": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_political_science_and_sociology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_psychology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_public_safety": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_railway_and_automotive_engineering": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_real_estate": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_refrigerating_machinery": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_social_welfare": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_stem": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_stem_tasks": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_taxation": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    "kmmlu_telecommunications_and_wireless_technology": f"{BASE_IMPORT}kmmlu_mc:KMMLUMultipleChoiceExtractor",
    # Generate_until (CoT) subtasks → kmmlu_cot.py (evaluator_name = "generation")
    "kmmlu_cot_hard": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_accounting": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_agricultural_sciences": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_applied_science": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_applied_science_tasks": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_aviation_engineering_and_maintenance": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_biology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_chemical_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_chemistry": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_civil_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_computer_science": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_construction": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_criminal_law": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_ecology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_economics": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_education": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_electrical_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_electronics_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_energy_management": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_environmental_science": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_fashion": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_food_processing": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_gas_technology_and_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_geomatics": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_health": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_humss": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_humss_tasks": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_industrial_engineer": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_information_technology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_interior_architecture_and_design": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_korean_history": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_law": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_machine_design_and_manufacturing": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_management": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_maritime_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_marketing": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_materials_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_math": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_mechanical_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_nondestructive_testing": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_other": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_other_tasks": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_patent": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_political_science_and_sociology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_psychology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_public_safety": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_railway_and_automotive_engineering": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_real_estate": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_refrigerating_machinery": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_social_welfare": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_stem": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_stem_tasks": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_taxation": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
    "kmmlu_cot_hard_telecommunications_and_wireless_technology": f"{BASE_IMPORT}kmmlu_cot:KMMLUCotExtractor",
}
